=====
Django Admin Monitoring
=====

todo: add description

Usage
-----------

1. Install this package using pip::

    pip install django_admin_monitoring

2. Add "admin_monitoring" in your INSTALLED_APPS setting::

    INSTALLED_APPS = (
        ...
        'admin_monitoring',
    )

3. todo::

    write the other readme stuff here